@@ -4,7 +4,7 @@ from functools import partial
 
 from cook import plugins
 from cook.mesos import read_file
-from cook.querying import get_compute_cluster_config, query_unique_and_run, parse_entity_refs
+from cook.querying import query_unique_and_run, parse_entity_refs
 from cook.util import check_positive, guard_no_cluster
 
 CHUNK_SIZE = 4096
@@ -105,15 +105,15 @@ def tail_follow(file_size, read_fn, follow_sleep_seconds):
 
         time.sleep(follow_sleep_seconds)
 
-def tail_using_read_file(instance, sandbox_dir_fn, path, num_lines_to_print, follow, follow_sleep_seconds):
-    retrieve_fn = plugins.get_fn('read-job-instance-file', read_file)
+def tail_using_read_file(instance, sandbox_dir_fn, path, num_lines_to_print, follow, follow_sleep_seconds, retrieve_fn_name='read-job-instance-file'):
+    retrieve_fn = plugins.get_fn(retrieve_fn_name, read_file)
     read = partial(retrieve_fn, instance=instance, sandbox_dir_fn=sandbox_dir_fn, path=path)
     file_size = read()['offset']
     tail_backwards(file_size, read, num_lines_to_print)
     if follow:
         tail_follow(file_size, read, follow_sleep_seconds)
 
-def kubectl_tail_instance_file(instance_uuid, _, path, num_lines_to_print, follow):
+def kubectl_tail_instance_file(instance_uuid, path, num_lines_to_print, follow, _):
     args = ['kubectl', 'kubectl',
             'exec',
             '-c', os.getenv('COOK_CONTAINER_NAME_FOR_JOB', 'required-cook-job-container'),
@@ -125,7 +125,7 @@ def kubectl_tail_instance_file(instance_uuid, _, path, num_lines_to_print, follo
     os.execlp(*args)
 
 
-def tail_for_instance(job, instance, sandbox_dir_fn, cluster, path, num_lines_to_print, follow, follow_sleep_seconds):
+def tail_for_instance(_, instance, sandbox_dir_fn, __, path, num_lines_to_print, follow, follow_sleep_seconds):
     """
     Tails the contents of the Mesos sandbox path for the given instance. If follow is truthy, it will
     try and read more data from the file until the user terminates. This assumes files will not shrink.
@@ -133,11 +133,9 @@ def tail_for_instance(job, instance, sandbox_dir_fn, cluster, path, num_lines_to
     """
     compute_cluster = instance["compute-cluster"]
     compute_cluster_type = compute_cluster["type"]
-    compute_cluster_name = compute_cluster["name"]
     if compute_cluster_type == "kubernetes" and ("end_time" not in instance or instance["end_time"] is None):
-        kubectl_tail_instance_file_fn = plugins.get_fn('kubectl-tail-instance-file', kubectl_tail_instance_file)
-        compute_cluster_config = get_compute_cluster_config(cluster, compute_cluster_name)
-        kubectl_tail_instance_file_fn(job["user"], instance["task_id"], compute_cluster_config, path, num_lines_to_print, follow)
+        kubernetes_tail_instance_file_fn = plugins.get_fn('kubernetes-tail-instance-file', kubectl_tail_instance_file)
+        kubernetes_tail_instance_file_fn(instance["task_id"], path, num_lines_to_print, follow, follow_sleep_seconds)
     else:
         tail_using_read_file(instance, sandbox_dir_fn, path, num_lines_to_print, follow, follow_sleep_seconds)
 
